@@ -1,6 +1,6 @@
 package Bundle::ABH;
 
-$VERSION = "1.01";
+$VERSION = "1.02";
 #$VERSION = sprintf("%d.%02d", q$Revision: 1.0 $ =~ /(\d+)\.(\d+)/);   
 
 1;
@@ -39,6 +39,8 @@ Devel::Peek
 
 MIME::Base64
 
+IO::ScalarArray      - For MIME::Tools
+
 MIME::Tools
 
 Tie::Handle
@@ -81,6 +83,10 @@ App::Config         - For cpan-upload
 
 MIME::Lite          - So nice and easy to send a MIME thingy
 
+Set::IntRange
+
+XML::Parser
+
 =head1 DESCRIPTION
 
 This bundle defines most of the modules Ask Bjoern Hansen usually
